@@ -1,8 +1,8 @@
-use 5.012;
+use 5.006;
 use warnings;
 
 package SQL::Interpol;
-$SQL::Interpol::VERSION = '1.100';
+$SQL::Interpol::VERSION = '1.101';
 # ABSTRACT: interpolate Perl variables into SQL statements
 
 use Exporter::Tidy all => [ qw( sql_interp sql ) ];
@@ -18,11 +18,14 @@ sub sql_interp {
 
 
 package SQL::Interpol::Parser;
-$SQL::Interpol::Parser::VERSION = '1.100';
+$SQL::Interpol::Parser::VERSION = '1.101';
 use Object::Tiny::Lvalue qw( alias_id bind );
 
 use Carp ();
 
+use constant IDENT_RX => qr/[a-zA-Z_][a-zA-Z0-9_\$\.]*/;
+use constant VALID => { ARRAY => 1, SCALAR => 1, 'SQL::Interpol' => 1, '' => 1 };
+
 sub _error { Carp::croak 'SQL::Interpol error: ', @_ }
 
 sub new {
@@ -33,8 +36,6 @@ sub new {
 sub parse {
     my $self = shift;
 
-    state $ident_rx = qr/[a-zA-Z_][a-zA-Z0-9_\$\.]*/;
-
     my $sql = '';
     my $bind = $self->bind;
 
@@ -57,7 +58,7 @@ sub parse {
         if ( not $type ) {
             $prev = $append = $item;
         }
-        elsif ( $sql =~ s/(\s*$ident_rx\s+(NOT\s+)?IN)\s*$//i ) {
+        elsif ( $sql =~ s/(\s*${(IDENT_RX)}\s+(NOT\s+)?IN)\s*$//oi ) {
             my @value
                 = 'SCALAR' eq $type ? $$item
                 : 'ARRAY'  eq $type ? @$item
@@ -66,7 +67,7 @@ sub parse {
             my $list = @value && join ', ', $self->bind_or_parse_values( @value );
             $append = @value ? "$1 ($list)" : $2 ? '1=1' : '1=0';
         }
-        elsif ( $sql =~ /\b(REPLACE|INSERT)[\w\s]*\sINTO\s*$ident_rx\s*$/i ) {
+        elsif ( $sql =~ /\b(REPLACE|INSERT)[\w\s]*\sINTO\s*${(IDENT_RX)}\s*$/oi ) {
             my @value
                 = 'SCALAR' eq $type ? $$item
                 : 'ARRAY'  eq $type ? @$item
@@ -115,7 +116,7 @@ sub parse {
             _error 'table reference has zero rows' if not @$item; # improve?
 
             # e.g. [[1,2],[3,4]] or [{a=>1,b=>2},{a=>3,b=>4}].
-            my $do_alias = $sql =~ /(?:\bFROM|JOIN)\s*$/i && ( $_[0] // '' ) !~ /\s*AS\b/i;
+            my $do_alias = $sql =~ /(?:\bFROM|JOIN)\s*$/i && ( $_[0] || '' ) !~ /\s*AS\b/i;
 
             my $row0  = $item->[0];
             my $type0 = ref $row0;
@@ -156,11 +157,13 @@ sub bind_or_parse_values {
     my $self = shift;
     map {
         my $type = ref;
-        _error "unrecognized $type value in aggregate" if $type and 'HASH' eq $type;
+        _error "unrecognized $type value in aggregate" unless VALID->{ $type };
         $type ? $self->parse( $_ ) : ( '?', push @{ $self->bind }, $_ )[0];
     } @_;
 }
 
+undef *VALID, *IDENT_RX;
+
 1;
 
 __END__
@@ -175,7 +178,7 @@ SQL::Interpol - interpolate Perl variables into SQL statements
 
 =head1 VERSION
 
-version 1.100
+version 1.101
 
 =head1 SYNOPSIS
 
@@ -391,8 +394,8 @@ latter may load too much meaning into the syntax of C<{}>, C<[]> and C<\>, there
 rendering the meaning less clear:
 
   SQL::Abstract example:
-  %where = (lname => {like => '%son%'},
-            age   => [-and => {'>=', 10}, {'<=', 20}])
+  %where = (lname => {like => '%son'},
+            age   => {'>=', 10, '<=', 20})
   Plain SQL:
   "lname LIKE '%son' AND (age >= 10 AND age <= 20)"
 
